@@ -44,7 +44,11 @@ notebooks = [
     'expimap_surgery_pipeline_basic.ipynb',
     'expimap_surgery_pipeline_advanced.ipynb',
     'treeArches_pbmc.ipynb',
-    'treeArches_identifying_new_ct.ipynb'
+    'treeArches_identifying_new_ct.ipynb',
+    'SageNet_mouse_embryo.ipynb',
+    'mvTCR_borcherding.ipynb',
+    'multigrate.ipynb',
+    'scpoli_surgery_pipeline.ipynb'
 ]
 
 for nb in notebooks:
@@ -56,7 +60,7 @@ for nb in notebooks:
 # -- Project information -----------------------------------------------------
 
 project = 'scArches'
-author = 'Marco Wagenstetter, Mohammad Lotfollahi, Mohsen Naghipourfar, Sergei Rybakov'
+author = ' Mohammad Lotfollahi, Sergei Rybakov, Mohsen Naghipourfar'
 copyright = f'{datetime.now():%Y}, ' + author
 
 pygments_style = 'sphinx'
